package Perinci::To::Text::I18N;

use parent 'Perinci::To::PackageBase::I18N';

our $VERSION = '0.20'; # VERSION

1;
# ABSTRACT: Project class for Perinci::To::Text

__END__

=pod

=encoding utf-8

=head1 NAME

Perinci::To::Text::I18N - Project class for Perinci::To::Text

=head1 VERSION

version 0.20

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
